//StarCatV, Star Catalog Visualization Tool
// (C) 1999  Jim Campbell   jc@izzy.net
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU  General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//                                                                
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of 
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details. 
//                                      
// You should have received a copy of the GNU General Public License 
// along with this software (see COPYING); if not, write to the 
// Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

// VMath.h: interface for the CVMath class.
//
//////////////////////////////////////////////////////////////////////
//#if !defined(AFX_VMATH_H__D7FB0902_7344_11D3_AB4E_444553540000__INCLUDED_)
//#define AFX_VMATH_H__D7FB0902_7344_11D3_AB4E_444553540000__INCLUDED_

//#if _MSC_VER >= 1000
//#pragma once
//#endif // _MSC_VER >= 1000

#include "StarViewStruc.h"
#include "Novas.h"
#include "astro.h"

class CVMath  
{
public:
	Novas N;
	Castro astro;

	CVMath();
	virtual ~CVMath();
	POLARVEC DistVec(const STARDATA &Ref1,const STARDATA &Ref2);
	RECTVEC CrossProd(const RECTVEC &a,const RECTVEC &b);
	RECTVEC StoRect(const double &RA,const double &Dec );
	void RecttoS(const double &x, const double &y, 
				const double &z,
		         double *RA, double *Dec);
	double DotProd(const RECTVEC &a,const RECTVEC &b);
	POLARVEC FXYtoPol(const int &x, const int &y, 
						const int &xCen, const int &yCen, 
						const float &HVAng);
	STARDATA VecRot(const STARDATA &Org, 
					const float &Dist, 
					const float &Ang);
	float CDist(const int &x1,const int &y1,
				const int &x2, const int &y2);

	RECTVEC AltAztoRect(const double &Alt,const double &Az );

	void Celest2AltAz(const double &Lat, const double &Long, const double &JD,
						    const double &RAdeg,const double &Dec,
							double &Alt, double &Az);

	double RectMag(const RECTVEC &Vec);
	void RAdeg2RAhm(double RAdeg,
					 float &RAh,float &RAm);
	void deg2dms(double deg,
				float *d,float *m, float *s);
	void DecStr(double deg, char *Out);
	void RAStr(double RAdeg, char *Out);
	void RAdeg2RAhms(double RAdeg,
					float *RAh,float *RAm, float *RAs);
	void GetObjectData(int Object,double JD, int Mode,
					double *RAdeg,double *Dec,
					double *Dia);
	void GetMoonData(double JD, double *RAdeg,double *Dec,
					double *Dia);
	void PlanetPosStr( char * out, double JulianDate, 
						int Equinox,double Lat, double Long);
	void FigurePlanetInfo(double JD,int EMode,int CMode,
							double Lat, double Long,
							STARDATA Zenith);
	void GetPlanetInfo(int Object,
						double *RAdeg,double *Dec,
						double *Dia, double *Dist,
						double *Alt, double *Az,
						double *L, double *B,double *R);

	//Planet globals:
	double PlanInfo[12][9];	//PlanInfo[n][ ] = Object number
							//PlanInfo[n][0] = Radeg
							//PlanInfo[n][1] = Dec
							//PlanInfo[n][2] = Dia
							//PlanInfo[n][3] = Dist
							//PlanInfo[n][4] = Alt
							//PlanInfo[n][5] = Az
							//PlanInfo[n][6] = L
							//PlanInfo[n][7] = B
							//PlanInfo[n][8] = R
	char PlanInfoStr[2000];
	
};

//#endif // !defined(AFX_VMATH_H__D7FB0902_7344_11D3_AB4E_444553540000__INCLUDED_)
